@@ -18,7 +18,7 @@
 #include <KompareDiff2/Difference>
 #include <KompareDiff2/DiffModel>
 #include <KompareDiff2/DiffModelList>
-#include <KompareDiff2/KompareModelList>
+#include <KompareDiff2/ModelList>
 
 #include <komparenavviewdebug.h>
 
@@ -26,15 +26,11 @@
 #define COL_DESTINATION   1
 #define COL_DIFFERENCE    2
 
-using namespace Diff2;
+using namespace KompareDiff2;
 
 KompareNavTreePart::KompareNavTreePart(QWidget* parentWidget, QObject* parent,
                                        const KPluginMetaData& metaData, const QVariantList&)
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     : KParts::ReadOnlyPart(parent, metaData),
-#else
-    : KParts::ReadOnlyPart(parent),
-#endif
       m_splitter(nullptr),
       m_modelList(nullptr),
       m_srcDirTree(nullptr),
@@ -49,10 +45,6 @@ KompareNavTreePart::KompareNavTreePart(QWidget* parentWidget, QObject* parent,
       m_destination(),
       m_info(nullptr)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    setMetaData(metaData);
-#endif
-
     m_splitter = new QSplitter(Qt::Horizontal, parentWidget);
 
     setWidget(m_splitter);
@@ -107,7 +99,7 @@ KompareNavTreePart::~KompareNavTreePart()
     m_selectedDifference = nullptr;
 }
 
-void KompareNavTreePart::slotKompareInfo(struct Kompare::Info* info)
+void KompareNavTreePart::slotKompareInfo(KompareDiff2::Info* info)
 {
     m_info = info;
 }
@@ -160,7 +152,7 @@ void KompareNavTreePart::buildTreeInMemory()
 
     switch (m_info->mode)
     {
-    case Kompare::ShowingDiff:
+    case KompareDiff2::ShowingDiff:
         // BUG: 107489 No common root because it is a multi directory relative path diff
         // We need to detect this and create a different rootitem / or so or should we always add this?
         // Trouble we run into is that the directories do not start with a /
@@ -175,11 +167,11 @@ void KompareNavTreePart::buildTreeInMemory()
         if (destBase[0] != QLatin1Char('/'))
             destBase.clear();
         break;
-    case Kompare::ComparingFiles:
+    case KompareDiff2::ComparingFiles:
         srcBase  = model->sourcePath();
         destBase = model->destinationPath();
         break;
-    case Kompare::ComparingDirs:
+    case KompareDiff2::ComparingDirs:
         srcBase = m_info->localSource;
         if (!srcBase.endsWith(QLatin1Char('/')))
             srcBase += QLatin1Char('/');
@@ -187,8 +179,8 @@ void KompareNavTreePart::buildTreeInMemory()
         if (!destBase.endsWith(QLatin1Char('/')))
             destBase += QLatin1Char('/');
         break;
-    case Kompare::BlendingFile:
-    case Kompare::BlendingDir:
+    case KompareDiff2::BlendingFile:
+    case KompareDiff2::BlendingDir:
     default:
         qCDebug(KOMPARENAVVIEW) << "Oops needs to implement this..." ;
     }
@@ -431,8 +423,8 @@ void KompareNavTreePart::slotApplyDifference(bool /*apply*/)
 
 void KompareNavTreePart::slotApplyAllDifferences(bool /*apply*/)
 {
-    QHash<const Diff2::Difference*, KChangeLVI*>::ConstIterator it = m_diffToChangeItemDict.constBegin();
-    QHash<const Diff2::Difference*, KChangeLVI*>::ConstIterator end = m_diffToChangeItemDict.constEnd();
+    QHash<const KompareDiff2::Difference*, KChangeLVI*>::ConstIterator it = m_diffToChangeItemDict.constBegin();
+    QHash<const KompareDiff2::Difference*, KChangeLVI*>::ConstIterator end = m_diffToChangeItemDict.constEnd();
 
     qCDebug(KOMPARENAVVIEW) << "m_diffToChangeItemDict.count() = " << m_diffToChangeItemDict.count() ;
 
@@ -602,13 +594,14 @@ const QString KFileLVI::getIcon(const QString& fileName)
     return QStringLiteral("text-plain");
 }
 
-void KFileLVI::fillChangesList(QTreeWidget* changesList, QHash<const Diff2::Difference*, KChangeLVI*>* diffToChangeItemDict)
+void KFileLVI::fillChangesList(QTreeWidget* changesList, QHash<const KompareDiff2::Difference*, KChangeLVI*>* diffToChangeItemDict)
 {
     changesList->clear();
     diffToChangeItemDict->clear();
 
-    DifferenceListConstIterator diffIt = m_model->differences()->constBegin();
-    DifferenceListConstIterator dEnd   = m_model->differences()->constEnd();
+    const DifferenceList* differences = m_model->differences();
+    DifferenceListConstIterator diffIt = differences->constBegin();
+    DifferenceListConstIterator dEnd   = differences->constEnd();
 
     for (; diffIt != dEnd; ++diffIt)
     {
@@ -647,7 +640,7 @@ KDirLVI::KDirLVI(KDirLVI* parent, const QString& dir) : QTreeWidgetItem(parent)
 }
 
 // addModel always removes it own path from the beginning
-void KDirLVI::addModel(QString& path, DiffModel* model, QHash<const Diff2::DiffModel*, KDirLVI*>* modelToDirItemDict)
+void KDirLVI::addModel(QString& path, DiffModel* model, QHash<const KompareDiff2::DiffModel*, KDirLVI*>* modelToDirItemDict)
 {
 //     qCDebug(KOMPARENAVVIEW) << "KDirLVI::addModel called with path = " << path << " from KDirLVI with m_dirName = " << m_dirName ;
 
@@ -698,7 +691,7 @@ KDirLVI* KDirLVI::findChild(const QString& dir)
     return nullptr;
 }
 
-void KDirLVI::fillFileList(QTreeWidget* fileList, QHash<const Diff2::DiffModel*, KFileLVI*>* modelToFileItemDict)
+void KDirLVI::fillFileList(QTreeWidget* fileList, QHash<const KompareDiff2::DiffModel*, KFileLVI*>* modelToFileItemDict)
 {
     fileList->clear();
 
